"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IDL = exports.PROGRAM_ID = void 0;
const web3_js_1 = require("@solana/web3.js");
exports.PROGRAM_ID = new web3_js_1.PublicKey('brdgGYmhGdaAJmqLN9oSp4381Ywc51vUfzn9NaSZC1d');
// TODO: anchor update chucks space error (likely not enough reserved space to upgrade the idl
// still working out how to resize)
exports.IDL = {
    version: '0.3.0',
    name: 'bridge',
    instructions: [
        {
            name: 'initializeBridgeV1',
            accounts: [
                {
                    name: 'owner',
                    isMut: true,
                    isSigner: true,
                    docs: [
                        'Whoever initializes the config will be the owner of the program. Signer',
                        'for creating the [`SenderConfig`] and [`RedeemerConfig`] accounts.',
                    ],
                },
                {
                    name: 'bridge',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'redeemerConfig',
                    isMut: true,
                    isSigner: false,
                    docs: [
                        'Redeemer Config account, which saves program data useful for other',
                        'instructions, specifically for inbound transfers. Also saves the payer',
                        "of the [`initialize`](crate::initialize) instruction as the program's",
                        'owner.',
                    ],
                },
                {
                    name: 'wormholeProgram',
                    isMut: false,
                    isSigner: false,
                    docs: ['Wormhole program.'],
                },
                {
                    name: 'tokenBridgeProgram',
                    isMut: false,
                    isSigner: false,
                    docs: ['Token Bridge program.'],
                },
                {
                    name: 'tokenBridgeConfig',
                    isMut: false,
                    isSigner: false,
                    docs: [
                        'Token Bridge config. Token Bridge program needs this account to',
                        'invoke the Wormhole program to post messages. Even though it is a',
                        'required account for redeeming token transfers, it is not actually',
                        'used for completing these transfers.',
                    ],
                },
                {
                    name: 'tokenBridgeAuthoritySigner',
                    isMut: false,
                    isSigner: false,
                    docs: [
                        'data; it is purely just a signer for SPL tranfers when it is delegated',
                        'spending approval for the SPL token.',
                    ],
                },
                {
                    name: 'tokenBridgeCustodySigner',
                    isMut: false,
                    isSigner: false,
                    docs: [
                        'data; it is purely just a signer for Token Bridge SPL tranfers.',
                    ],
                },
                {
                    name: 'tokenBridgeMintAuthority',
                    isMut: false,
                    isSigner: false,
                    docs: [
                        'data; it is purely just a signer (SPL mint authority) for Token Bridge',
                        'wrapped assets.',
                    ],
                },
                {
                    name: 'rndrMint',
                    isMut: false,
                    isSigner: false,
                },
                {
                    name: 'rndrEscrow',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'wrndrMint',
                    isMut: true,
                    isSigner: false,
                    docs: [
                        'Token Bridge wrapped mint info. This is the SPL token that will be',
                        'bridged from the foreign contract. The wrapped mint PDA must agree',
                        "with the native token's metadata in the wormhole message. Mutable.",
                    ],
                },
                {
                    name: 'wrndrEscrow',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'wormholeBridge',
                    isMut: false,
                    isSigner: false,
                    docs: ['Wormhole bridge data account (a.k.a. its config).'],
                },
                {
                    name: 'tokenBridgeEmitter',
                    isMut: false,
                    isSigner: false,
                    docs: [
                        'that holds data; it is purely just a signer for posting Wormhole',
                        'messages on behalf of the Token Bridge program.',
                    ],
                },
                {
                    name: 'wormholeFeeCollector',
                    isMut: false,
                    isSigner: false,
                    docs: [
                        'Wormhole fee collector account, which requires lamports before the',
                        'program can post a message (if there is a fee). Token Bridge program',
                        'handles the fee payments.',
                    ],
                },
                {
                    name: 'tokenBridgeSequence',
                    isMut: false,
                    isSigner: false,
                    docs: [
                        "Token Bridge emitter's sequence account. Like with all Wormhole",
                        'emitters, this account keeps track of the sequence number of the last',
                        'posted message.',
                    ],
                },
                {
                    name: 'circuitBreaker',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'circuitBreakerProgram',
                    isMut: false,
                    isSigner: false,
                },
                {
                    name: 'tokenProgram',
                    isMut: false,
                    isSigner: false,
                },
                {
                    name: 'associatedTokenProgram',
                    isMut: false,
                    isSigner: false,
                },
                {
                    name: 'systemProgram',
                    isMut: false,
                    isSigner: false,
                    docs: ['System program.'],
                },
            ],
            args: [
                {
                    name: 'args',
                    type: {
                        defined: 'InitializeBridgeArgsV1',
                    },
                },
            ],
        },
        {
            name: 'registerForeignContractV1',
            accounts: [
                {
                    name: 'owner',
                    isMut: true,
                    isSigner: true,
                    docs: [
                        'Owner of the program set in the [`SenderConfig`] account. Signer for',
                        'creating [`ForeignContract`] account.',
                    ],
                },
                {
                    name: 'bridge',
                    isMut: false,
                    isSigner: false,
                },
                {
                    name: 'rndrMint',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'wrndrMint',
                    isMut: true,
                    isSigner: false,
                    docs: [
                        'Token Bridge wrapped mint info. This is the SPL token that will be',
                        'bridged from the foreign contract. The wrapped mint PDA must agree',
                        "with the native token's metadata in the wormhole message. Mutable.",
                    ],
                },
                {
                    name: 'foreignContract',
                    isMut: true,
                    isSigner: false,
                    docs: [
                        'Foreign Contract account. Create this account if an emitter has not been',
                        'registered yet for this Wormhole chain ID. If there already is a',
                        'contract address saved in this account, overwrite it.',
                    ],
                },
                {
                    name: 'tokenBridgeForeignEndpoint',
                    isMut: false,
                    isSigner: false,
                    docs: [
                        'Token Bridge foreign endpoint. This account should really be one',
                        "endpoint per chain, but Token Bridge's PDA allows for multiple",
                        'endpoints for each chain. We store the proper endpoint for the',
                        'emitter chain.',
                    ],
                },
                {
                    name: 'tokenBridgeProgram',
                    isMut: false,
                    isSigner: false,
                    docs: ['Token Bridge program.'],
                },
                {
                    name: 'systemProgram',
                    isMut: false,
                    isSigner: false,
                    docs: ['System program.'],
                },
            ],
            args: [
                {
                    name: 'args',
                    type: {
                        defined: 'RegisterForeignContractArgsV1',
                    },
                },
            ],
        },
        {
            name: 'receiveRenderV2',
            accounts: [
                {
                    name: 'payer',
                    isMut: true,
                    isSigner: true,
                    docs: ['Payer will pay Wormhole fee to transfer tokens'],
                },
                {
                    name: 'emissionSchedule',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'emissionDistributorProgram',
                    isMut: false,
                    isSigner: false,
                },
                {
                    name: 'payerTokenAccount',
                    isMut: true,
                    isSigner: false,
                    docs: ['associated token account.'],
                },
                {
                    name: 'config',
                    isMut: false,
                    isSigner: false,
                    docs: [
                        'Redeemer Config account. Acts as the Token Bridge redeemer, which signs',
                        'for the complete transfer instruction. Read-only.',
                    ],
                },
                {
                    name: 'foreignContract',
                    isMut: false,
                    isSigner: false,
                    docs: [
                        'Foreign Contract account. The registered contract specified in this',
                        "account must agree with the target address for the Token Bridge's token",
                        'transfer. Read-only.',
                    ],
                },
                {
                    name: 'bridge',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'wrndrMint',
                    isMut: true,
                    isSigner: false,
                    docs: [
                        'Token Bridge wrapped mint info. This is the SPL token that will be',
                        'bridged from the foreign contract. The wrapped mint PDA must agree',
                        "with the native token's metadata in the wormhole message. Mutable.",
                    ],
                },
                {
                    name: 'wrndrEscrow',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'rndrMint',
                    isMut: false,
                    isSigner: false,
                },
                {
                    name: 'rndrEscrow',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'recipientAta',
                    isMut: true,
                    isSigner: false,
                    docs: ['Recipient associated token account.'],
                },
                {
                    name: 'recipient',
                    isMut: true,
                    isSigner: false,
                    docs: ['transaction.'],
                },
                {
                    name: 'wormholeProgram',
                    isMut: false,
                    isSigner: false,
                    docs: ['Wormhole program.'],
                },
                {
                    name: 'tokenBridgeProgram',
                    isMut: false,
                    isSigner: false,
                    docs: ['Token Bridge program.'],
                },
                {
                    name: 'tokenBridgeWrappedMeta',
                    isMut: false,
                    isSigner: false,
                    docs: [
                        "Token Bridge program's wrapped metadata, which stores info",
                        'about the token from its native chain:',
                        '* Wormhole Chain ID',
                        "* Token's native contract address",
                        "* Token's native decimals",
                    ],
                },
                {
                    name: 'tokenBridgeConfig',
                    isMut: false,
                    isSigner: false,
                    docs: ['Token Bridge config. Read-only.'],
                },
                {
                    name: 'vaa',
                    isMut: false,
                    isSigner: false,
                    docs: [
                        'Verified Wormhole message account. The Wormhole program verified',
                        'signatures and posted the account data here. Read-only.',
                    ],
                },
                {
                    name: 'tokenBridgeClaim',
                    isMut: true,
                    isSigner: false,
                    docs: [
                        'is true if the bridged assets have been claimed. If the transfer has',
                        'not been redeemed, this account will not exist yet.',
                    ],
                },
                {
                    name: 'tokenBridgeForeignEndpoint',
                    isMut: false,
                    isSigner: false,
                    docs: [
                        'Token Bridge foreign endpoint. This account should really be one',
                        'endpoint per chain, but the PDA allows for multiple endpoints for each',
                        'chain! We store the proper endpoint for the emitter chain.',
                    ],
                },
                {
                    name: 'tokenBridgeMintAuthority',
                    isMut: false,
                    isSigner: false,
                },
                {
                    name: 'systemProgram',
                    isMut: false,
                    isSigner: false,
                    docs: ['System program.'],
                },
                {
                    name: 'tokenProgram',
                    isMut: false,
                    isSigner: false,
                    docs: ['Token program.'],
                },
                {
                    name: 'associatedTokenProgram',
                    isMut: false,
                    isSigner: false,
                    docs: ['Associated Token program.'],
                },
                {
                    name: 'rent',
                    isMut: false,
                    isSigner: false,
                    docs: ['Rent sysvar.'],
                },
                {
                    name: 'transfer',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'upgradePoints',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'totalPoints',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'circuitBreaker',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'circuitBreakerProgram',
                    isMut: false,
                    isSigner: false,
                },
            ],
            args: [
                {
                    name: 'args',
                    type: {
                        defined: 'ReceiveRenderArgsV2',
                    },
                },
            ],
        },
        {
            name: 'updateBridgeV1',
            accounts: [
                {
                    name: 'bridge',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'authority',
                    isMut: false,
                    isSigner: true,
                },
            ],
            args: [
                {
                    name: 'args',
                    type: {
                        defined: 'UpdateBridgeArgsV1',
                    },
                },
            ],
        },
        {
            name: 'initializeUpgradeRewardsV0',
            accounts: [
                {
                    name: 'rndrMint',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'rndrMintBreaker',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'circuitBreaker',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'circuitBreakerProgram',
                    isMut: false,
                    isSigner: false,
                },
                {
                    name: 'upgradeRewardsEscrow',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'admin',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'authority',
                    isMut: false,
                    isSigner: true,
                },
                {
                    name: 'payer',
                    isMut: true,
                    isSigner: true,
                },
                {
                    name: 'systemProgram',
                    isMut: false,
                    isSigner: false,
                },
                {
                    name: 'tokenProgram',
                    isMut: false,
                    isSigner: false,
                },
            ],
            args: [
                {
                    name: 'args',
                    type: {
                        defined: 'InitializeUpgradeRewardsArgsV0',
                    },
                },
            ],
        },
        {
            name: 'distributeUpgradeRewardsV0',
            accounts: [
                {
                    name: 'emissionSchedule',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'emissionScheduleReceipt',
                    isMut: false,
                    isSigner: false,
                },
                {
                    name: 'emissionDistributorProgram',
                    isMut: false,
                    isSigner: false,
                },
                {
                    name: 'upgradePoints',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'totalPoints',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'aggUserUpgradePoints',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'aggTotalPoints',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'to',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'upgradeRewardsEscrow',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'admin',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'rndrMint',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'circuitBreaker',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'circuitBreakerProgram',
                    isMut: false,
                    isSigner: false,
                },
                {
                    name: 'tokenProgram',
                    isMut: false,
                    isSigner: false,
                },
                {
                    name: 'recipient',
                    isMut: true,
                    isSigner: false,
                },
                {
                    name: 'payer',
                    isMut: true,
                    isSigner: true,
                },
                {
                    name: 'systemProgram',
                    isMut: false,
                    isSigner: false,
                },
            ],
            args: [
                {
                    name: 'args',
                    type: {
                        defined: 'DistributeUpgradeRewardsArgsV0',
                    },
                },
            ],
        },
    ],
    accounts: [
        {
            name: 'RedeemerConfig',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'owner',
                        docs: ["Program's owner."],
                        type: 'publicKey',
                    },
                    {
                        name: 'bump',
                        docs: ['PDA bump.'],
                        type: 'u8',
                    },
                    {
                        name: 'tokenBridge',
                        docs: ["Token Bridge program's relevant addresses."],
                        type: {
                            defined: 'InboundTokenBridgeAddresses',
                        },
                    },
                    {
                        name: 'space',
                        type: {
                            array: ['u8', 128],
                        },
                    },
                ],
            },
        },
        {
            name: 'ForeignContract',
            docs: ['Foreign emitter account data.'],
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'chain',
                        docs: ["Emitter chain. Cannot equal `1` (Solana's Chain ID)."],
                        type: 'u16',
                    },
                    {
                        name: 'address',
                        docs: ['Emitter address. Cannot be zero address.'],
                        type: {
                            array: ['u8', 32],
                        },
                    },
                    {
                        name: 'tokenBridgeForeignEndpoint',
                        docs: ["Token Bridge program's foreign endpoint account key."],
                        type: 'publicKey',
                    },
                    {
                        name: 'space',
                        type: {
                            array: ['u8', 128],
                        },
                    },
                ],
            },
        },
        {
            name: 'BridgeV1',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'authority',
                        type: 'publicKey',
                    },
                    {
                        name: 'rndrMint',
                        type: 'publicKey',
                    },
                    {
                        name: 'wrndrMint',
                        type: 'publicKey',
                    },
                    {
                        name: 'incentiveEpoch',
                        type: 'u64',
                    },
                    {
                        name: 'incentiveCounter',
                        type: 'u64',
                    },
                    {
                        name: 'incentiveThreshold',
                        type: 'u64',
                    },
                    {
                        name: 'bump',
                        type: 'u8',
                    },
                    {
                        name: 'space',
                        type: {
                            array: ['u8', 128],
                        },
                    },
                ],
            },
        },
        {
            name: 'TransferV2',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'solAddr',
                        type: 'publicKey',
                    },
                    {
                        name: 'sequence',
                        type: 'u64',
                    },
                    {
                        name: 'createdAt',
                        type: 'i64',
                    },
                    {
                        name: 'amount',
                        type: 'u64',
                    },
                    {
                        name: 'upgradeBracket',
                        type: 'u8',
                    },
                    {
                        name: 'priorSupply',
                        type: 'u64',
                    },
                    {
                        name: 'points',
                        type: 'u64',
                    },
                    {
                        name: 'bump',
                        type: 'u8',
                    },
                    {
                        name: 'space',
                        type: {
                            array: ['u8', 128],
                        },
                    },
                ],
            },
        },
        {
            name: 'UpgradePointsV0',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'epochId',
                        type: 'u64',
                    },
                    {
                        name: 'solAddr',
                        type: 'publicKey',
                    },
                    {
                        name: 'points',
                        type: 'u64',
                    },
                    {
                        name: 'claimed',
                        type: 'bool',
                    },
                    {
                        name: 'bump',
                        type: 'u8',
                    },
                    {
                        name: 'amountRewarded',
                        type: 'u64',
                    },
                    {
                        name: 'aggPoints',
                        type: 'u64',
                    },
                    {
                        name: 'agged',
                        type: 'bool',
                    },
                    {
                        name: 'space1',
                        type: {
                            array: ['u8', 64],
                        },
                    },
                    {
                        name: 'space2',
                        type: {
                            array: ['u8', 32],
                        },
                    },
                    {
                        name: 'space3',
                        type: {
                            array: ['u8', 15],
                        },
                    },
                ],
            },
        },
        {
            name: 'AggUserUpgradePointsV0',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'solAddr',
                        type: 'publicKey',
                    },
                    {
                        name: 'points',
                        type: 'u64',
                    },
                    {
                        name: 'bump',
                        type: 'u8',
                    },
                    {
                        name: 'epochsClaimed',
                        type: {
                            array: ['bool', 128],
                        },
                    },
                    {
                        name: 'space',
                        type: {
                            array: ['u8', 128],
                        },
                    },
                ],
            },
        },
        {
            name: 'TotalUpgradePointsV0',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'epochId',
                        type: 'u64',
                    },
                    {
                        name: 'points',
                        type: 'u64',
                    },
                    {
                        name: 'bump',
                        type: 'u8',
                    },
                    {
                        name: 'aggPoints',
                        type: 'u64',
                    },
                    {
                        name: 'agged',
                        type: 'bool',
                    },
                    {
                        name: 'space1',
                        type: {
                            array: ['u8', 64],
                        },
                    },
                    {
                        name: 'space2',
                        type: {
                            array: ['u8', 32],
                        },
                    },
                    {
                        name: 'space3',
                        type: {
                            array: ['u8', 23],
                        },
                    },
                ],
            },
        },
        {
            name: 'AggTotalUpgradePointsV0',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'points',
                        type: 'u64',
                    },
                    {
                        name: 'bump',
                        type: 'u8',
                    },
                    {
                        name: 'currEpoch',
                        type: 'u64',
                    },
                    {
                        name: 'space',
                        type: {
                            array: ['u8', 128],
                        },
                    },
                ],
            },
        },
        {
            name: 'AdminV0',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'rndrMint',
                        type: 'publicKey',
                    },
                    {
                        name: 'authority',
                        type: 'publicKey',
                    },
                    {
                        name: 'backfillAuthority',
                        type: 'publicKey',
                    },
                    {
                        name: 'bump',
                        type: 'u8',
                    },
                    {
                        name: 'space',
                        type: {
                            array: ['u8', 128],
                        },
                    },
                ],
            },
        },
    ],
    types: [
        {
            name: 'WindowedCircuitBreakerConfigV0',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'windowSizeSeconds',
                        type: 'u64',
                    },
                    {
                        name: 'thresholdType',
                        type: {
                            defined: 'ThresholdType',
                        },
                    },
                    {
                        name: 'threshold',
                        type: 'u64',
                    },
                ],
            },
        },
        {
            name: 'DistributeUpgradeRewardsArgsV0',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'epochId',
                        type: 'u64',
                    },
                ],
            },
        },
        {
            name: 'InitializeBridgeArgsV1',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'ethTokenChain',
                        type: 'u16',
                    },
                    {
                        name: 'ethTokenAddress',
                        type: {
                            array: ['u8', 32],
                        },
                    },
                    {
                        name: 'config',
                        type: {
                            defined: 'WindowedCircuitBreakerConfigV0',
                        },
                    },
                    {
                        name: 'incentiveThreshold',
                        type: 'u64',
                    },
                ],
            },
        },
        {
            name: 'InitializeUpgradeRewardsArgsV0',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'authority',
                        type: 'publicKey',
                    },
                    {
                        name: 'backfillAuthority',
                        type: {
                            option: 'publicKey',
                        },
                    },
                    {
                        name: 'upgradesEscrowConfig',
                        type: {
                            defined: 'WindowedCircuitBreakerConfigV0',
                        },
                    },
                ],
            },
        },
        {
            name: 'ReceiveRenderArgsV2',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'vaaHash',
                        type: {
                            array: ['u8', 32],
                        },
                    },
                ],
            },
        },
        {
            name: 'RegisterForeignContractArgsV1',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'chain',
                        type: 'u16',
                    },
                    {
                        name: 'address',
                        type: {
                            array: ['u8', 32],
                        },
                    },
                ],
            },
        },
        {
            name: 'UpdateBridgeArgsV1',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'incentiveThreshold',
                        type: {
                            option: 'u64',
                        },
                    },
                ],
            },
        },
        {
            name: 'InboundTokenBridgeAddresses',
            type: {
                kind: 'struct',
                fields: [
                    {
                        name: 'config',
                        type: 'publicKey',
                    },
                    {
                        name: 'custodySigner',
                        type: 'publicKey',
                    },
                    {
                        name: 'mintAuthority',
                        type: 'publicKey',
                    },
                ],
            },
        },
        {
            name: 'ThresholdType',
            type: {
                kind: 'enum',
                variants: [
                    {
                        name: 'Percent',
                    },
                    {
                        name: 'Absolute',
                    },
                ],
            },
        },
        {
            name: 'BridgeMessage',
            docs: [
                'Expected message types for this program. Only valid payloads are:',
                '* `Transfer`: Payload ID == 1.',
                '',
                'Payload IDs are encoded as u8.',
            ],
            type: {
                kind: 'enum',
                variants: [
                    {
                        name: 'Transfer',
                        fields: [
                            {
                                name: 'recipient',
                                type: {
                                    array: ['u8', 32],
                                },
                            },
                        ],
                    },
                    {
                        name: 'TransferV2',
                        fields: [
                            {
                                name: 'recipient',
                                type: {
                                    array: ['u8', 32],
                                },
                            },
                        ],
                    },
                ],
            },
        },
    ],
    errors: [
        {
            code: 6000,
            name: 'InvalidWormholeBridge',
            msg: 'InvalidWormholeBridge',
        },
        {
            code: 6001,
            name: 'InvalidWormholeFeeCollector',
            msg: 'InvalidWormholeFeeCollector',
        },
        {
            code: 6002,
            name: 'InvalidWormholeEmitter',
            msg: 'InvalidWormholeEmitter',
        },
        {
            code: 6003,
            name: 'InvalidWormholeSequence',
            msg: 'InvalidWormholeSequence',
        },
        {
            code: 6004,
            name: 'InvalidSysvar',
            msg: 'InvalidSysvar',
        },
        {
            code: 6005,
            name: 'OwnerOnly',
            msg: 'OwnerOnly',
        },
        {
            code: 6006,
            name: 'BumpNotFound',
            msg: 'BumpNotFound',
        },
        {
            code: 6007,
            name: 'InvalidForeignContract',
            msg: 'InvalidForeignContract',
        },
        {
            code: 6008,
            name: 'ZeroBridgeAmount',
            msg: 'ZeroBridgeAmount',
        },
        {
            code: 6009,
            name: 'InvalidTokenBridgeConfig',
            msg: 'InvalidTokenBridgeConfig',
        },
        {
            code: 6010,
            name: 'InvalidTokenBridgeAuthoritySigner',
            msg: 'InvalidTokenBridgeAuthoritySigner',
        },
        {
            code: 6011,
            name: 'InvalidTokenBridgeCustodySigner',
            msg: 'InvalidTokenBridgeCustodySigner',
        },
        {
            code: 6012,
            name: 'InvalidTokenBridgeEmitter',
            msg: 'InvalidTokenBridgeEmitter',
        },
        {
            code: 6013,
            name: 'InvalidTokenBridgeSequence',
            msg: 'InvalidTokenBridgeSequence',
        },
        {
            code: 6014,
            name: 'InvalidTokenBridgeSender',
            msg: 'InvalidTokenBridgeSender',
        },
        {
            code: 6015,
            name: 'InvalidRecipient',
            msg: 'InvalidRecipient',
        },
        {
            code: 6016,
            name: 'InvalidTransferTokenAccount',
            msg: 'InvalidTransferTokenAccount',
        },
        {
            code: 6017,
            name: 'InvalidTransferToChain',
            msg: 'InvalidTransferTokenChain',
        },
        {
            code: 6018,
            name: 'InvalidTransferTokenChain',
            msg: 'InvalidTransferTokenChain',
        },
        {
            code: 6019,
            name: 'InvalidPayerAta',
            msg: 'InvalidPayerAta',
        },
        {
            code: 6020,
            name: 'InvalidTransferToAddress',
            msg: 'InvalidTransferToAddress',
        },
        {
            code: 6021,
            name: 'AlreadyRedeemed',
            msg: 'AlreadyRedeemed',
        },
        {
            code: 6022,
            name: 'InvalidTokenBridgeForeignEndpoint',
            msg: 'InvalidTokenBridgeForeignEndpoint',
        },
        {
            code: 6023,
            name: 'NonExistentRelayerAta',
            msg: 'NonExistentRelayerAta',
        },
        {
            code: 6024,
            name: 'InvalidTokenBridgeMintAuthority',
            msg: 'InvalidTokenBridgeMintAuthority',
        },
        {
            code: 6025,
            name: 'ReceiveAmountTooLarge',
            msg: 'ReceiveAmountTooLarge',
        },
        {
            code: 6026,
            name: 'InvalidTransferType',
            msg: 'InvalidTransferType',
        },
        {
            code: 6027,
            name: 'MintAddressMismatch',
            msg: 'MintAddressMismatch',
        },
        {
            code: 6028,
            name: 'TransferV0ShouldntExist',
            msg: 'TransferV0ShouldntExist',
        },
        {
            code: 6029,
            name: 'UnfinishedEpochRewards',
            msg: 'UnfinishedEpochRewards',
        },
        {
            code: 6030,
            name: 'UpgradeRewardsClaimed',
            msg: 'UpgradeRewardsClaimed',
        },
        {
            code: 6031,
            name: 'EpochIdOutOfRange',
            msg: 'EpochIdOutOfRange',
        },
        {
            code: 6032,
            name: 'PreviousUnclaimedEpoch',
            msg: 'PreviousUnclaimedEpoch',
        },
    ],
};
//# sourceMappingURL=constants.js.map