"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.bridgeResolvers = void 0;
const spl_utils_1 = require("@render-foundation/spl-utils");
const spl_utils_2 = require("@render-foundation/spl-utils");
const emission_distributor_sdk_1 = require("@render-foundation/emission-distributor-sdk");
const pdas_1 = require("./pdas");
const circuit_breaker_sdk_1 = require("@render-foundation/circuit-breaker-sdk");
exports.bridgeResolvers = (0, spl_utils_1.combineResolvers)(spl_utils_1.renderCommonResolver, (0, spl_utils_1.ataResolver)({
    instruction: 'initializeBridgeV1',
    account: 'rndrEscrow',
    mint: 'rndrMint',
    owner: 'bridge',
}), (0, spl_utils_1.ataResolver)({
    instruction: 'initializeBridgeV1',
    account: 'wrndrEscrow',
    mint: 'wrndrMint',
    owner: 'redeemerConfig',
}), (0, spl_utils_1.ataResolver)({
    instruction: 'receiveRenderV2',
    account: 'rndrEscrow',
    mint: 'rndrMint',
    owner: 'bridge',
}), (0, spl_utils_1.ataResolver)({
    instruction: 'receiveRenderOutOfBandV0',
    account: 'rndrEscrow',
    mint: 'rndrMint',
    owner: 'bridge',
}), (0, spl_utils_1.ataResolver)({
    instruction: 'receiveRenderV2',
    account: 'wrndrEscrow',
    mint: 'wrndrMint',
    owner: 'config',
}), (0, spl_utils_1.ataResolver)({
    instruction: 'receiveRenderOutOfBandV0',
    account: 'wrndrEscrow',
    mint: 'wrndrMint',
    owner: 'config',
}), (0, spl_utils_1.ataResolver)({
    instruction: 'receiveRenderV2',
    account: 'recipientAta',
    mint: 'rndrMint',
    owner: 'recipient',
}), (0, spl_utils_1.ataResolver)({
    instruction: 'receiveRenderOutOfBandV0',
    account: 'recipientAta',
    mint: 'rndrMint',
    owner: 'recipient',
}), (0, spl_utils_1.ataResolver)({
    instruction: 'distributeUpgradeRewardsV1',
    account: 'to',
    mint: 'rndrMint',
    owner: 'recipient',
}), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === 'emissionSchedule') {
        const rndrMintK = (0, spl_utils_2.get)(accounts, [
            ...path.slice(0, path.length - 1),
            'rndrMint',
        ]);
        const emissionDistributorPid = (0, spl_utils_2.get)(accounts, [
            ...path.slice(0, path.length - 1),
            'emissionDistributorProgram',
        ]);
        return (0, emission_distributor_sdk_1.emissionScheduleKey)(rndrMintK, emissionDistributorPid)[0];
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === 'admin') {
        return (0, pdas_1.adminKey)()[0];
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === 'upgradeRewardsEscrow') {
        const rndrMintK = (0, spl_utils_2.get)(accounts, [
            ...path.slice(0, path.length - 1),
            'rndrMint',
        ]);
        return (0, pdas_1.upgradeRewardsEscrow)(rndrMintK)[0];
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === 'circuitBreaker' &&
        (idlIx.name == 'distributeUpgradeRewardsV1' ||
            idlIx.name == 'initializeUpgradeRewardsV0')) {
        const escrowK = (0, spl_utils_2.get)(accounts, [
            ...path.slice(0, path.length - 1),
            'upgradeRewardsEscrow',
        ]);
        return (0, circuit_breaker_sdk_1.accountWindowedBreakerKey)(escrowK)[0];
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === 'aggTotalPoints') {
        return (0, pdas_1.aggTotalUpgradePointsKey)()[0];
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === 'aggTotalPoints') {
        const ownerK = (0, spl_utils_2.get)(accounts, [
            ...path.slice(0, path.length - 1),
            'recipient',
        ]);
        return (0, pdas_1.aggUserUpgradePointsKey)(ownerK)[0];
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, programId, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === 'upgradePoints' &&
        idlIx.name === 'receiveRenderV2') {
        const emissionDistributorPid = (0, spl_utils_2.get)(accounts, [
            ...path.slice(0, path.length - 1),
            'emissionDistributorProgram',
        ]);
        const program = yield (0, emission_distributor_sdk_1.init)(provider, emissionDistributorPid, true);
        const emissionScheduleK = (0, spl_utils_2.get)(accounts, [
            ...path.slice(0, path.length - 1),
            'emissionSchedule',
        ]);
        const ownerK = (0, spl_utils_2.get)(accounts, [
            ...path.slice(0, path.length - 1),
            'recipient',
        ]);
        const emissionSchedule = yield program.account.emissionScheduleV0.fetch(emissionScheduleK);
        return (0, pdas_1.upgradePointsKey)(ownerK, emissionSchedule.epochId.toNumber(), programId)[0];
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, programId, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === 'totalPoints' &&
        idlIx.name === 'receiveRenderV2') {
        const emissionDistributorPid = (0, spl_utils_2.get)(accounts, [
            ...path.slice(0, path.length - 1),
            'emissionDistributorProgram',
        ]);
        const program = yield (0, emission_distributor_sdk_1.init)(provider, emissionDistributorPid, true);
        const emissionScheduleK = (0, spl_utils_2.get)(accounts, [
            ...path.slice(0, path.length - 1),
            'emissionSchedule',
        ]);
        const emissionSchedule = yield program.account.emissionScheduleV0.fetch(emissionScheduleK);
        return (0, pdas_1.totalUpgradePointsKey)(emissionSchedule.epochId.toNumber(), programId)[0];
    }
})), (0, spl_utils_1.resolveIndividual)(({ path, accounts, idlIx, provider, args }) => __awaiter(void 0, void 0, void 0, function* () {
    if (path[path.length - 1] === 'rndrMintBreaker' &&
        idlIx.name == 'initializeUpgradeRewardsV0') {
        const rndrMintK = (0, spl_utils_2.get)(accounts, [
            ...path.slice(0, path.length - 1),
            'rndrMint',
        ]);
        console.log(`foomintbar ${rndrMintK}`);
        return (0, circuit_breaker_sdk_1.mintWindowedBreakerKey)(rndrMintK)[0];
    }
})));
//# sourceMappingURL=resolvers.js.map