import { PublicKey } from '@solana/web3.js';
import { PROGRAM_ID } from './constants';
import * as anchor from '@coral-xyz/anchor';
export function bridgeKey(rndrMint, wrndrMint, programId = PROGRAM_ID) {
    return PublicKey.findProgramAddressSync([Buffer.from('bridge', 'utf-8'), rndrMint.toBuffer(), wrndrMint.toBuffer()], programId);
}
export function transferV2Key(vaaMsg, programId = PROGRAM_ID) {
    return PublicKey.findProgramAddressSync([Buffer.from('transferv2', 'utf-8'), vaaMsg], programId);
}
export function transferOutOfBandV0Key(vaaMsg, programId = PROGRAM_ID) {
    return PublicKey.findProgramAddressSync([Buffer.from('transfer_out_of_bound_v0', 'utf-8'), vaaMsg], programId);
}
export function upgradePointsKey(recipient, epochId, programId = PROGRAM_ID) {
    return PublicKey.findProgramAddressSync([
        Buffer.from('upgrade_points', 'utf-8'),
        recipient.toBuffer(),
        new anchor.BN(epochId).toBuffer('le', 8),
    ], programId);
}
export function totalUpgradePointsKey(epochId, programId = PROGRAM_ID) {
    return PublicKey.findProgramAddressSync([
        Buffer.from('total_upgrade_points', 'utf-8'),
        new anchor.BN(epochId).toBuffer('le', 8),
    ], programId);
}
export function foreignContractKey(chain, programId = PROGRAM_ID) {
    return PublicKey.findProgramAddressSync([
        Buffer.from('foreign_contract'),
        (() => {
            const buf = Buffer.alloc(2);
            buf.writeUInt16LE(chain);
            return buf;
        })(),
    ], programId);
}
export function redeemerConfigKey(programId = PROGRAM_ID) {
    return PublicKey.findProgramAddressSync([Buffer.from('redeemer')], programId);
}
export function adminKey(programId = PROGRAM_ID) {
    return PublicKey.findProgramAddressSync([Buffer.from('admin')], programId);
}
export function aggTotalUpgradePointsKey(programId = PROGRAM_ID) {
    return PublicKey.findProgramAddressSync([Buffer.from('agg_total_upgrade_points', 'utf-8')], programId);
}
export function aggUserUpgradePointsKey(owner, programId = PROGRAM_ID) {
    return PublicKey.findProgramAddressSync([Buffer.from('agg_user_upgrade_points_v1', 'utf-8'), owner.toBuffer()], programId);
}
export function upgradeRewardsEscrow(rndrMint, programId = PROGRAM_ID) {
    return PublicKey.findProgramAddressSync([Buffer.from('upgrade_rewards', 'utf-8'), rndrMint.toBuffer()], programId);
}
//# sourceMappingURL=pdas.js.map