import { ataResolver, combineResolvers, renderCommonResolver, resolveIndividual, } from '@render-foundation/spl-utils';
import { get } from '@render-foundation/spl-utils';
import { emissionScheduleKey, init as initializeEmissionDistributor, } from '@render-foundation/emission-distributor-sdk';
import { adminKey, aggTotalUpgradePointsKey, aggUserUpgradePointsKey, totalUpgradePointsKey, upgradePointsKey, upgradeRewardsEscrow, } from './pdas';
import { accountWindowedBreakerKey, mintWindowedBreakerKey, } from '@render-foundation/circuit-breaker-sdk';
export const bridgeResolvers = combineResolvers(renderCommonResolver, ataResolver({
    instruction: 'initializeBridgeV1',
    account: 'rndrEscrow',
    mint: 'rndrMint',
    owner: 'bridge',
}), ataResolver({
    instruction: 'initializeBridgeV1',
    account: 'wrndrEscrow',
    mint: 'wrndrMint',
    owner: 'redeemerConfig',
}), ataResolver({
    instruction: 'receiveRenderV2',
    account: 'rndrEscrow',
    mint: 'rndrMint',
    owner: 'bridge',
}), ataResolver({
    instruction: 'receiveRenderOutOfBandV0',
    account: 'rndrEscrow',
    mint: 'rndrMint',
    owner: 'bridge',
}), ataResolver({
    instruction: 'receiveRenderV2',
    account: 'wrndrEscrow',
    mint: 'wrndrMint',
    owner: 'config',
}), ataResolver({
    instruction: 'receiveRenderOutOfBandV0',
    account: 'wrndrEscrow',
    mint: 'wrndrMint',
    owner: 'config',
}), ataResolver({
    instruction: 'receiveRenderV2',
    account: 'recipientAta',
    mint: 'rndrMint',
    owner: 'recipient',
}), ataResolver({
    instruction: 'receiveRenderOutOfBandV0',
    account: 'recipientAta',
    mint: 'rndrMint',
    owner: 'recipient',
}), ataResolver({
    instruction: 'distributeUpgradeRewardsV1',
    account: 'to',
    mint: 'rndrMint',
    owner: 'recipient',
}), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === 'emissionSchedule') {
        const rndrMintK = get(accounts, [
            ...path.slice(0, path.length - 1),
            'rndrMint',
        ]);
        const emissionDistributorPid = get(accounts, [
            ...path.slice(0, path.length - 1),
            'emissionDistributorProgram',
        ]);
        return emissionScheduleKey(rndrMintK, emissionDistributorPid)[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === 'admin') {
        return adminKey()[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === 'upgradeRewardsEscrow') {
        const rndrMintK = get(accounts, [
            ...path.slice(0, path.length - 1),
            'rndrMint',
        ]);
        return upgradeRewardsEscrow(rndrMintK)[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === 'circuitBreaker' &&
        (idlIx.name == 'distributeUpgradeRewardsV1' ||
            idlIx.name == 'initializeUpgradeRewardsV0')) {
        const escrowK = get(accounts, [
            ...path.slice(0, path.length - 1),
            'upgradeRewardsEscrow',
        ]);
        return accountWindowedBreakerKey(escrowK)[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === 'aggTotalPoints') {
        return aggTotalUpgradePointsKey()[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === 'aggTotalPoints') {
        const ownerK = get(accounts, [
            ...path.slice(0, path.length - 1),
            'recipient',
        ]);
        return aggUserUpgradePointsKey(ownerK)[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, programId, args }) => {
    if (path[path.length - 1] === 'upgradePoints' &&
        idlIx.name === 'receiveRenderV2') {
        const emissionDistributorPid = get(accounts, [
            ...path.slice(0, path.length - 1),
            'emissionDistributorProgram',
        ]);
        const program = await initializeEmissionDistributor(provider, emissionDistributorPid, true);
        const emissionScheduleK = get(accounts, [
            ...path.slice(0, path.length - 1),
            'emissionSchedule',
        ]);
        const ownerK = get(accounts, [
            ...path.slice(0, path.length - 1),
            'recipient',
        ]);
        const emissionSchedule = await program.account.emissionScheduleV0.fetch(emissionScheduleK);
        return upgradePointsKey(ownerK, emissionSchedule.epochId.toNumber(), programId)[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, programId, args }) => {
    if (path[path.length - 1] === 'totalPoints' &&
        idlIx.name === 'receiveRenderV2') {
        const emissionDistributorPid = get(accounts, [
            ...path.slice(0, path.length - 1),
            'emissionDistributorProgram',
        ]);
        const program = await initializeEmissionDistributor(provider, emissionDistributorPid, true);
        const emissionScheduleK = get(accounts, [
            ...path.slice(0, path.length - 1),
            'emissionSchedule',
        ]);
        const emissionSchedule = await program.account.emissionScheduleV0.fetch(emissionScheduleK);
        return totalUpgradePointsKey(emissionSchedule.epochId.toNumber(), programId)[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === 'rndrMintBreaker' &&
        idlIx.name == 'initializeUpgradeRewardsV0') {
        const rndrMintK = get(accounts, [
            ...path.slice(0, path.length - 1),
            'rndrMint',
        ]);
        console.log(`foomintbar ${rndrMintK}`);
        return mintWindowedBreakerKey(rndrMintK)[0];
    }
}));
//# sourceMappingURL=resolvers.js.map