/// <reference types="node" />
import { PublicKey, PublicKeyInitData, TransactionInstruction } from '@solana/web3.js';
import { Mint } from '@solana/spl-token';
import { ChainId, ParsedTokenTransferVaa, SignedVaa } from '@certusone/wormhole-sdk';
import { Program } from '@coral-xyz/anchor';
import { Bridge } from '@render-foundation/idls/lib/types/bridge';
import BN from 'bn.js';
export interface BridgeAccounts {
    rndrMint: PublicKey;
    bridgeK: PublicKey;
    circuitBreakerK: PublicKey;
}
export declare function receiveRenderOutOfBoundV0Ix(program: Program<Bridge>, payer: PublicKeyInitData, tokenBridgeProgramId: PublicKeyInitData, wormholeProgramId: PublicKeyInitData, wormholeMessage: SignedVaa | ParsedTokenTransferVaa, accts: BridgeAccounts): Promise<TransactionInstruction>;
export declare function createReceiveRndrV2Ix(program: Program<Bridge>, payer: PublicKeyInitData, tokenBridgeProgramId: PublicKeyInitData, wormholeProgramId: PublicKeyInitData, wormholeMessage: SignedVaa | ParsedTokenTransferVaa, accts: BridgeAccounts): Promise<TransactionInstruction>;
export declare function getCompleteTransferWrappedWithPayloadCpiAccounts(tokenBridgeProgramId: PublicKeyInitData, wormholeProgramId: PublicKeyInitData, payer: PublicKeyInitData, vaa: SignedVaa | ParsedTokenTransferVaa): {
    payer: PublicKey;
    tokenBridgeConfig: PublicKey;
    vaa: PublicKey;
    tokenBridgeClaim: PublicKey;
    tokenBridgeForeignEndpoint: PublicKey;
    tokenBridgeRedeemer: PublicKey;
    tokenBridgeWrappedMint: PublicKey;
    tokenBridgeWrappedMeta: PublicKey;
    tokenBridgeMintAuthority: PublicKey;
    rent: PublicKey;
    systemProgram: PublicKey;
    tokenProgram: PublicKey;
    wormholeProgram: PublicKey;
};
export interface WindowCircuitBreakerConfig {
    windowSizeSeconds: BN;
    thresholdType: any;
    threshold: BN;
}
export interface InitializeArgs {
    ethTokenAddress: number[];
    ethTokenChain: ChainId;
    incentiveThreshold: BN;
    config: WindowCircuitBreakerConfig;
}
export interface InitializeAccounts {
    owner: PublicKey;
    rndrMint: Mint;
    wRndrMint: PublicKey;
    bridgeK: PublicKey;
    circuitBreakerK: PublicKey;
}
export declare const initializeUpgradeRewardsV0Ix: (program: Program<Bridge>, rndrMint: PublicKey, args: {
    authority: PublicKey;
    backfillAuthority?: PublicKey;
    upgradesEscrowConfig: WindowCircuitBreakerConfig;
}, accts: {
    authority: PublicKey;
}) => Promise<TransactionInstruction>;
export declare const distributeUpgradeRewardsV1Ix: (program: Program<Bridge>, epochId: number, rndrMint: PublicKey, accts: {
    recipient: PublicKey;
    payer?: PublicKey;
}) => Promise<TransactionInstruction>;
export declare function createInitializeIx(program: Program<Bridge>, tokenBridgeProgramId: PublicKeyInitData, wormholeProgramId: PublicKeyInitData, accts: InitializeAccounts, args: InitializeArgs): Promise<TransactionInstruction>;
export declare function createRegisterForeignContractIx(program: Program<Bridge>, payer: PublicKeyInitData, tokenBridgeProgramId: PublicKeyInitData, chain: ChainId, contractAddress: Buffer, tokenBridgeForeignAddress: string, rndrMint: PublicKey, wrndrMint: PublicKey): Promise<TransactionInstruction>;
//# sourceMappingURL=instructions.d.ts.map